@@ -206,9 +206,7 @@ class BatchOperator(BaseOperator):
         self.scheduling_priority_override = scheduling_priority_override
         self.array_properties = array_properties
         self.parameters = parameters or {}
-        self.retry_strategy = retry_strategy or {}
-        if not self.retry_strategy.get("attempts", None):
-            self.retry_strategy["attempts"] = 1
+        self.retry_strategy = retry_strategy
         self.waiters = waiters
         self.tags = tags or {}
         self.wait_for_completion = wait_for_completion
